about summary refs log tree commit diff
path: root/src/libstd
diff options
context:
space:
mode:
authorVadim Chugunov <vadimcn@gmail.com>2014-08-23 01:12:59 -0700
committerVadim Chugunov <vadimcn@gmail.com>2014-08-23 02:11:28 -0700
commit68811817f723e57354b0137b1c9bc6b28016ecbc (patch)
tree3e048892bc46aac9fa1ed871d3fabf040fb2ec86 /src/libstd
parent8c994a1237d1c79811920cf852d0b801b8518336 (diff)
Complete renaming of win32 to windows
Diffstat (limited to 'src/libstd')
-rw-r--r--src/libstd/io/mod.rs2
-rw-r--r--src/libstd/os.rs12
2 files changed, 7 insertions, 7 deletions
diff --git a/src/libstd/io/mod.rs b/src/libstd/io/mod.rs
index e93a958acc6..dc6478df360 100644
--- a/src/libstd/io/mod.rs
+++ b/src/libstd/io/mod.rs
@@ -348,7 +348,7 @@ impl IoError {
                 // libuv maps this error code to EISDIR. we do too. if it is found
                 // to be incorrect, we can add in some more machinery to only
                 // return this message when ERROR_INVALID_FUNCTION after certain
-                // win32 calls.
+                // Windows calls.
                 libc::ERROR_INVALID_FUNCTION => (InvalidInput,
                                                  "illegal operation on a directory"),
 
diff --git a/src/libstd/os.rs b/src/libstd/os.rs
index bcdec2e0631..ad666d70034 100644
--- a/src/libstd/os.rs
+++ b/src/libstd/os.rs
@@ -139,7 +139,7 @@ pub fn getcwd() -> Path {
 }
 
 #[cfg(windows)]
-pub mod win32 {
+pub mod windows {
     use libc::types::os::arch::extra::DWORD;
     use libc;
     use option::{None, Option};
@@ -362,7 +362,7 @@ pub fn getenv_as_bytes(n: &str) -> Option<Vec<u8>> {
 pub fn getenv(n: &str) -> Option<String> {
     unsafe {
         with_env_lock(|| {
-            use os::win32::{fill_utf16_buf_and_decode};
+            use os::windows::{fill_utf16_buf_and_decode};
             let n: Vec<u16> = n.utf16_units().collect();
             let n = n.append_one(0);
             fill_utf16_buf_and_decode(|buf, sz| {
@@ -707,7 +707,7 @@ pub fn self_exe_name() -> Option<Path> {
     #[cfg(windows)]
     fn load_self() -> Option<Vec<u8>> {
         unsafe {
-            use os::win32::fill_utf16_buf_and_decode;
+            use os::windows::fill_utf16_buf_and_decode;
             fill_utf16_buf_and_decode(|buf, sz| {
                 libc::GetModuleFileNameW(0u as libc::DWORD, buf, sz)
             }).map(|s| s.into_string().into_bytes())
@@ -1315,7 +1315,7 @@ pub fn page_size() -> uint {
 
 /// A memory mapped file or chunk of memory. This is a very system-specific
 /// interface to the OS's memory mapping facilities (`mmap` on POSIX,
 /// `VirtualAlloc`/`CreateFileMapping` on win32). It makes no attempt at
 /// abstracting platform differences, besides in error values returned. Consider
 /// yourself warned.
 ///
@@ -1385,7 +1385,7 @@ pub enum MapError {
     ErrZeroLength,
     /// Unrecognized error. The inner value is the unrecognized errno.
     ErrUnknown(int),
     /// ## The following are win32-specific
     ///
     /// Unsupported combination of protection flags
     /// (`MapReadable`/`MapWritable`/`MapExecutable`).
@@ -1849,7 +1849,7 @@ pub mod consts {
     pub static FAMILY: &'static str = "windows";
 
     /// A string describing the specific operating system in use: in this
-    /// case, `win32`.
+    /// case, `windows`.
     pub static SYSNAME: &'static str = "windows";
 
     /// Specifies the filename prefix used for shared libraries on this
@@ -1315,7 +1315,7 @@ pub fn page_size() -> uint {
 /// A memory mapped file or chunk of memory. This is a very system-specific
 /// interface to the OS's memory mapping facilities (`mmap` on POSIX,
-/// `VirtualAlloc`/`CreateFileMapping` on win32). It makes no attempt at
+/// `VirtualAlloc`/`CreateFileMapping` on Windows). It makes no attempt at
 /// abstracting platform differences, besides in error values returned. Consider
 /// yourself warned.
@@ -1385,7 +1385,7 @@ pub enum MapError {
     /// Unrecognized error. The inner value is the unrecognized errno.
     ErrUnknown(int),
-    /// ## The following are win32-specific
+    /// ## The following are Windows-specific
     ///
     /// Unsupported combination of protection flags